# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).


## [1.2.0] - 2021-11-30

### Changed

- Minimum requirements
  - Python 3.7
  - Alliance Auth v2.9.3


## [1.1.0] - 2021-11-24

### Added

- Error handling on connection problems to ESI status URL
- Tests


## [1.0.5] - 2021-07-08

### Added

- Checked for compatibility with Python 3.9 and Django 3.2


## [1.0.4] - 2021-01-12

### Removed

- Support for Django 2


## [1.0.3] - 2021-01-11

### Fixed

- Local variable might be referenced before being initialized


## [1.0.1] - 2020-12-16

### Added

- UserAgent for calls to ESI

### Fixed

- Bootstrap classes used in template


## [1.0.0] - 2020-10-12

- first official release


## [0.1.0-alpha.3] - 2020-10-11

### Fixed

- including the right directory in MANIFEST

### Added

- Warning when ESI status couldn't be loaded, for what ever reason


## [0.1.0-alpha.2] - 2020-10-11

### Changed

- Link to image in README updated since GitHub changed the default **master** branch to _main_. Fucking stupid change ...


## [0.1.0-alpha.1] - 2020-10-11

### Added

- initial version for testing purposes
